==> N2SNUserTools-0.2.tar.gz: N2SNUserTools-0.2/setup.py <==
from os import path
from setuptools import setup, find_packages
import sys
import versioneer


# NOTE: This file must remain Python 2 compatible for the foreseeable future,
# to ensure that we error out properly for people with outdated setuptools
# and/or pip.
min_version = (3, 6)
if sys.version_info < min_version:
    error = """
N2SNUserTools does not support Python {0}.{1}.
Python {2}.{3} and above is required. Check your Python version like so:

python3 --version

This may be due to an out-of-date pip. Make sure you have pip >= 9.0.1.
Upgrade pip like so:

pip install --upgrade pip
""".format(*(sys.version_info[:2] + min_version))
    sys.exit(error)

here = path.abspath(path.dirname(__file__))

with open(path.join(here, 'README.rst'), encoding='utf-8') as readme_file:
    readme = readme_file.read()

with open(path.join(here, 'requirements.txt')) as requirements_file:
    # Parse requirements.txt, ignoring any commented-out lines.
    requirements = [line for line in requirements_file.read().splitlines()
                    if not line.startswith('#')]


setup(
    name='N2SNUserTools',
    version=versioneer.get_version(),
    cmdclass=versioneer.get_cmdclass(),
    description="User Manipulation Tools for Python",
    long_description=readme,
    author="Brookhaven National Laboratory",
    author_email='swilkins@bnl.gov',
    url='https://github.com/NSLS-II/N2SNUserTools',
    python_requires='>={}'.format('.'.join(str(n) for n in min_version)),
    packages=find_packages(exclude=['docs', 'tests']),
    entry_points={
        'console_scripts': [
            'n2sn_list_users = N2SNUserTools.cli:n2sn_list_users',
            'n2sn_list_staff = N2SNUserTools.cli:n2sn_list_staff',
            'n2sn_add_user = N2SNUserTools.cli:n2sn_add_user',
            'n2sn_remove_user = N2SNUserTools.cli:n2sn_remove_user',
            'n2sn_search_user = N2SNUserTools.cli:n2sn_search_user',
        ],
    },
    include_package_data=True,
    package_data={
        'N2SNUserTools': [
            # When adding files here, remember to update MANIFEST.in as well,
            # or else they will not be included in the distribution on PyPI!
            # 'path/to/data_file',
        ]
    },
    install_requires=requirements,
    license="BSD (3-clause)",
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
    ],
)

==> N2SNUserTools-0.2.2.tar.gz: N2SNUserTools-0.2.2/setup.py <==
from os import path
from setuptools import setup, find_packages
import sys
import versioneer


# NOTE: This file must remain Python 2 compatible for the foreseeable future,
# to ensure that we error out properly for people with outdated setuptools
# and/or pip.
min_version = (3, 6)
if sys.version_info < min_version:
    error = """
N2SNUserTools does not support Python {0}.{1}.
Python {2}.{3} and above is required. Check your Python version like so:

python3 --version

This may be due to an out-of-date pip. Make sure you have pip >= 9.0.1.
Upgrade pip like so:

pip install --upgrade pip
""".format(*(sys.version_info[:2] + min_version))
    sys.exit(error)

here = path.abspath(path.dirname(__file__))

with open(path.join(here, 'README.rst'), encoding='utf-8') as readme_file:
    readme = readme_file.read()

with open(path.join(here, 'requirements.txt')) as requirements_file:
    # Parse requirements.txt, ignoring any commented-out lines.
    requirements = [line for line in requirements_file.read().splitlines()
                    if not line.startswith('#')]


setup(
    name='N2SNUserTools',
    version=versioneer.get_version(),
    cmdclass=versioneer.get_cmdclass(),
    description="User Manipulation Tools for Python",
    long_description=readme,
    author="Brookhaven National Laboratory",
    author_email='swilkins@bnl.gov',
    url='https://github.com/NSLS-II/N2SNUserTools',
    python_requires='>={}'.format('.'.join(str(n) for n in min_version)),
    packages=find_packages(exclude=['docs', 'tests']),
    entry_points={
        'console_scripts': [
            'n2sn_list_users = N2SNUserTools.cli:n2sn_list_users',
            'n2sn_list_offline_users = N2SNUserTools.cli:n2sn_list_offline_users',
            'n2sn_list_staff = N2SNUserTools.cli:n2sn_list_staff',
            'n2sn_search_user = N2SNUserTools.cli:n2sn_search_user',
            'n2sn_add_user = N2SNUserTools.cli:n2sn_add_user',
            'n2sn_remove_user = N2SNUserTools.cli:n2sn_remove_user',
            'n2sn_add_offline_user = N2SNUserTools.cli:n2sn_add_offline_user',
            'n2sn_remove_offline_user = N2SNUserTools.cli:n2sn_remove_offline_user',
        ],
    },
    include_package_data=True,
    package_data={
        'N2SNUserTools': [
            # When adding files here, remember to update MANIFEST.in as well,
            # or else they will not be included in the distribution on PyPI!
            # 'path/to/data_file',
        ]
    },
    install_requires=requirements,
    license="BSD (3-clause)",
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
    ],
)
